@@ -15,7 +15,15 @@ from dateutil.relativedelta import relativedelta
 from django.contrib.auth.decorators import login_required
 from django.contrib.auth.mixins import LoginRequiredMixin
 from django.core.paginator import EmptyPage, PageNotAnInteger, Paginator
-from django.db.models import DecimalField, ExpressionWrapper, F, Q, Sum, Value
+from django.db.models import (
+    Count,
+    DecimalField,
+    ExpressionWrapper,
+    F,
+    Q,
+    Sum,
+    Value,
+)
 from django.db.models.functions import Coalesce
 from django.http import HttpResponse
 from django.shortcuts import get_object_or_404, redirect, render
@@ -1597,39 +1605,69 @@ class CanteenWorkBook:
             & Q(is_disabled=False)
             & Q(is_ignorable=False)
         ).all()
-        month_days = [
-            self.date_start + timedelta(days=i)
-            for i in range((self.date_end - self.date_start).days)
-        ]
-        month_days.append(self.date_end)
 
-        sundays = [d for d in month_days if d.weekday() == 6]
+        consumptions = []
+        for ingredient in ingredients:
+            consumptions += [
+                c
+                for c in ingredient.consumptions.filter(
+                    Q(date_of_using__lte=self.date_end) & Q(is_disabled=False)
+                ).all()
+            ]
 
+        inventory_days = []
+        dates_of_using = sorted(
+            list(set([c.date_of_using for c in consumptions]))
+        )
+        for i, date_of_using in enumerate(dates_of_using):
+            if i + 1 < len(dates_of_using):
+                if (date_of_using + timedelta(days=1)) < dates_of_using[i + 1]:
+                    inventory_days.append(date_of_using)
+            else:
+                inventory_days.append(date_of_using)
+
+        if len(inventory_days) < 1:
+            inventory_days.insert(-1, self.date_end)
+
+        inventory_days.insert(
+            0, (self.date_start.replace(day=1) - timedelta(days=1))
+        )
         formed_ingredients = []
-        for sunday in sundays:
-            sunday_ingredients = []
+        for inventory_day in inventory_days:
+            inventory_day_ingredients = []
             for ingredient in ingredients:
+                if (
+                    ingredient.storage_date > inventory_day
+                    and inventory_day != inventory_days[-1]
+                ):
+                    continue
                 remaining_quantity = ingredient.quantity - sum(
                     [
                         c.amount_used
                         for c in ingredient.consumptions.filter(
                             Q(is_disabled=False)
+                            & Q(date_of_using__lte=inventory_day)
                         ).all()
-                        if c.date_of_using <= sunday
                     ]
                 )
                 if remaining_quantity > Decimal("0.0"):
-                    sunday_ingredients.append(ingredient)
-                    print(ingredient.name, remaining_quantity)
-            form_count = len(sunday_ingredients) / ingredient_rows_count
+                    inventory_day_ingredients.append(ingredient)
+            form_count = len(inventory_day_ingredients) / ingredient_rows_count
             surplus_ingredients_len = (
-                len(sunday_ingredients) % ingredient_rows_count
+                len(inventory_day_ingredients) % ingredient_rows_count
             )
             fake_ingredients_len = (
                 ingredient_rows_count - surplus_ingredients_len
             )
-            s_ingredient0 = sunday_ingredients[0]
-            sunday_ingredients += [
+
+            inventory_day_ingredients = sorted(
+                inventory_day_ingredients, key=lambda i: i.category.name
+            )
+
+            if len(inventory_day_ingredients) < 1:
+                continue
+            s_ingredient0 = inventory_day_ingredients[0]
+            inventory_day_ingredients += [
                 Ingredient(
                     user=user,
                     storage_date=self.date_start,
@@ -1644,22 +1682,22 @@ class CanteenWorkBook:
                 )
                 for i in range(fake_ingredients_len)
             ]
-
-            sunday_ingredients = sorted(
-                sunday_ingredients, key=lambda i: i.category.name
-            )
             for index in range(
-                0, len(sunday_ingredients), ingredient_rows_count
+                0, len(inventory_day_ingredients), ingredient_rows_count
             ):
-                split_ingredients = sunday_ingredients[
+                split_ingredients = inventory_day_ingredients[
                     index : index + ingredient_rows_count
                 ]
 
-                formed_ingredients.append([sunday, index, split_ingredients])
+                formed_ingredients.append(
+                    [inventory_day, index, split_ingredients]
+                )
 
-        for index, (sunday, sunday_index, ingredients) in enumerate(
-            formed_ingredients
-        ):
+        for index, (
+            inventory_day,
+            inventory_day_index,
+            ingredients,
+        ) in enumerate(formed_ingredients):
 
             title_row_num = (ingredient_rows_count + 8) * index + 1
             title_cell = sheet.cell(title_row_num, 1)
@@ -1682,9 +1720,9 @@ class CanteenWorkBook:
                 )
             ).format(
                 affiliation=user.affiliation,
-                year=sunday.year,
-                month=sunday.month,
-                day=sunday.day,
+                year=inventory_day.year,
+                month=inventory_day.month,
+                day=inventory_day.day,
             )
 
             sub_title_affiliation_date_cell.font = self.font_12
@@ -1755,6 +1793,7 @@ class CanteenWorkBook:
             )
 
             summary_total_price = Decimal("0.0")
+            formed_ingredients_index = index
             for index, ingredient in enumerate(ingredients):
                 ingredient_row_num = header1_row_num + index + 1
                 ingredient_quantity = (
@@ -1763,9 +1802,9 @@ class CanteenWorkBook:
                         [
                             c.amount_used
                             for c in ingredient.consumptions.filter(
-                                is_disabled=False
+                                Q(date_of_using__lte=inventory_day)
+                                & Q(is_disabled=False)
                             ).all()
-                            if c.date_of_using <= sunday
                         ]
                     )
                     if ingredient.id
@@ -1776,37 +1815,50 @@ class CanteenWorkBook:
                 )
                 summary_total_price += ingredient_total_price
 
-                sheet.cell(ingredient_row_num, 1, ingredient.name)
+                ingredient_name_cell = sheet.cell(ingredient_row_num, 1)
+                ingredient_name_cell.value = ingredient.name
+                if ingredient.name:
+                    ingredient_name_cell.comment = Comment(
+                        _("{meal_type} ({category})").format(
+                            meal_type=ingredient.meal_type,
+                            category=ingredient.category,
+                        ),
+                        user.username,
+                    )
                 sheet.cell(ingredient_row_num, 2, ingredient.quantity_unit_name)
-                sheet.cell(ingredient_row_num, 3, ingredient_quantity)
-                sheet.cell(ingredient_row_num, 4, ingredient_total_price)
-                sheet.cell(ingredient_row_num, 5, ingredient_quantity)
-                sheet.cell(ingredient_row_num, 6, ingredient_total_price)
+                sheet.cell(ingredient_row_num, 3, ingredient_quantity or "")
+                sheet.cell(ingredient_row_num, 4, ingredient_total_price or "")
+                sheet.cell(ingredient_row_num, 5, ingredient_quantity or "")
+                sheet.cell(ingredient_row_num, 6, ingredient_total_price or "")
                 sheet.cell(ingredient_row_num, 7, "")
                 sheet.cell(ingredient_row_num, 8, "")
                 sheet.cell(ingredient_row_num, 9, "")
 
             summary_row_num = header1_row_num + ingredient_rows_count + 1
 
-            prev_sunday = (
-                formed_ingredients[index - 1][0]
-                if 0 <= index - 1 < len(formed_ingredients)
+            prev_inventory_day = (
+                formed_ingredients[formed_ingredients_index - 1][0]
+                if 0 <= formed_ingredients_index - 1 < len(formed_ingredients)
                 else None
             )
-            next_sunday = (
-                storaged_ingredients[index + 1][0]
-                if 0 < index + 1 < (len(formed_ingredients) - 1)
+            next_inventory_day = (
+                formed_ingredients[formed_ingredients_index + 1][0]
+                if 0 < formed_ingredients_index + 1 < len(formed_ingredients)
                 else None
             )
-            summary_1_value = ""
+            summary_col1_value = ""
 
-            if not next_sunday or not next_sunday == sunday:
-                summary_1_value = _("Summary Total Price (Surplus Sheet)")
+            if next_inventory_day and next_inventory_day == inventory_day:
+                summary_col1_value = _(
+                    "Sub0-summary Total Price (Surplus Sheet)"
+                )
+            else:
+                summary_col1_value = _("Summary Total Price (Surplus Sheet)")
                 summary_total_price = Decimal("0.0")
                 ingredients_list = [
                     __ingredients
-                    for __sunday, __sunday_index, __ingredients in formed_ingredients
-                    if __sunday == sunday
+                    for __inventory_day, __inventory_day_index, __ingredients in formed_ingredients
+                    if __inventory_day == inventory_day
                 ]
                 for ingredients in ingredients_list:
                     for ingredient in ingredients:
@@ -1815,7 +1867,8 @@ class CanteenWorkBook:
                                 [
                                     c.amount_used
                                     for c in ingredient.consumptions.filter(
-                                        is_disabled=False
+                                        Q(is_disabled=False)
+                                        & Q(date_of_using__lte=inventory_day)
                                     ).all()
                                 ]
                             )
@@ -1826,10 +1879,7 @@ class CanteenWorkBook:
                             ingredient_quantity * ingredient.unit_price
                         )
 
-            else:
-                summary_1_value = _("Sub0-summary Total Price (Surplus Sheet)")
-
-            sheet.cell(summary_row_num, 1, summary_1_value)
+            sheet.cell(summary_row_num, 1, summary_col1_value)
 
             sheet.cell(summary_row_num, 4, summary_total_price)
             sheet.cell(summary_row_num, 6, summary_total_price)
@@ -2068,8 +2118,10 @@ class CanteenWorkBook:
 
 
 def get_workbook_zip(request, month):
-    meal_types = MealType.objects.filter(
-        Q(user=request.user) & Q(is_disabled=False)
+    meal_types = MealType.objects.annotate(
+        ingredients_count=Count("ingredients")
+    ).filter(
+        Q(user=request.user) & Q(is_disabled=False) & Q(ingredients_count__gt=0)
     )
 
     zip_buffer = io.BytesIO()
